@@ -22,6 +22,8 @@
 use super::BacktrackingRecorder;
 use super::BacktrackingState::*;
 
+/// An iterator over a historical record which produces references to historical
+/// elements
 pub struct ReferencingBacktrackingIterator<'record, Iter> where Iter: Iterator {
   recorder: &'record mut BacktrackingRecorder<Iter>,
 }
@@ -41,7 +43,9 @@ impl<'record, Iter> Iterator for ReferencingBacktrackingIterator<'record, Iter>
     /// Produce a borrow on the vec which should be valid
     /// We borrow the vec for the lifetime of 'record, so we should
     /// be able to produce a reference for the lifetime of 'record,
-    /// so long as we never remove items from the vec
+    /// so long as we never remove items from the vec - which only
+    /// happens with a `forget`, which requires a mutable borrow on
+    /// the parent `Record`, which we already hold!
     macro_rules! unsafe_backtracking_index {
       ($index:expr) => {
         unsafe {
@@ -94,19 +98,6 @@ impl<'record, Iter> BacktrackingIterator for ReferencingBacktrackingIterator<'re
   fn backtrack(&mut self, position: usize) {
     self.recorder.state = Backtracking { position };
   }
-
-  fn forget_before(&mut self, position: usize) {
-    if position <= self.recorder.backtracking_vec.len() {
-      //Split the history at the given point
-      let kept = self.recorder.backtracking_vec.split_off(position);
-      //Keep the second half
-      self.recorder.backtracking_vec = kept;
-    }
-  }
-
-  fn forget(&mut self) {
-    self.recorder.backtracking_vec.clear();
-  }
 }
 
 use super::Walkbackable;
@@ -121,6 +112,8 @@ impl<'history, 'record, Iter: 'history> Walkbackable<'history> for ReferencingBa
   }
 }
 
+/// A backwalk through a `ReferencingBacktrackingIterator`'s history. Yields references to
+/// items in the history, and can be used to walk back to a desired point.
 pub struct ReferencingWalkback<'record, Iter> where Iter: Iterator {
   backtracker: &'record BacktrackingRecorder<Iter>,
   reverse_position: usize,
